/*!
 * VUEX-LOCALSTORAGE v0.2.0
 * (c) 2016 crossjs
 * Released under the MIT License.
 */
'use strict';

/**
 * createPersist
 * @param  {String} key             key
 * @param  {Object} [initialState]  初始值/默认值
 * @param  {Object} [config]        自定义 provider/serialize/deserialize/expires
 * @return {Object}                 get/set 方法
 */
var index = function (key, initialState, config) {
  if ( initialState === void 0 ) initialState = {};

  var ref = Object.assign({
    provider: localStorage,
    serialize: JSON.stringify,
    deserialize: JSON.parse,
    expires: 0 // never expires
  }, config);
  var provider = ref.provider;
  var serialize = ref.serialize;
  var deserialize = ref.deserialize;
  var expires = ref.expires;

  return {
    get: function get () {
      var state;

      try {
        var ref = deserialize(provider.getItem(key));
        var value = ref.value;
        var expires = ref.expires;
        if (expires === 0 || expires > Date.now()) {
          state = deserialize(value);
        }
      } catch (e) {
        // console.log(e)
      }

      return Object.assign({}, initialState, state)
    },
    set: function set (value) {
      try {
        provider.setItem(key, serialize({
          value: serialize(value),
          expires: expires ? expires + Date.now() : expires
        }));
      } catch (e) {
        // console.log(e)
      }
    }
  }
};

module.exports = index;
